/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-17 16:33:36.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.api.controller;

import cn.com.qmth.examcloud.commons.web.support.ControllerSupport;
import cn.com.qmth.examcloud.core.print.api.bean.UserInfo;
import cn.com.qmth.examcloud.core.print.common.Result;
import cn.com.qmth.examcloud.core.print.service.PrintingProjectService;
import cn.com.qmth.examcloud.core.print.service.bean.common.ExamInfo;
import cn.com.qmth.examcloud.core.print.service.bean.common.OrgInfo;
import cn.com.qmth.examcloud.core.print.service.bean.printingproject.PrintingProjectInfo;
import cn.com.qmth.examcloud.core.print.service.bean.printingproject.PrintingProjectQuery;
import com.google.common.collect.Lists;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.*;

import java.util.List;

import static cn.com.qmth.examcloud.core.print.common.Result.success;

/**
 * 印刷项目相关接口
 *
 * @author: fengdesheng
 * @since: 2018/10/17
 */
@RestController
@Api(tags = "印刷项目相关接口")
@RequestMapping("${$rmp.ctrl.print}/printing/project")
public class PrintingProjectController extends ControllerSupport {
    @Autowired
    private PrintingProjectService printingProjectService;

    @PostMapping("/list")
    @ApiOperation(value = "获取印刷项目列表(分页)")
    public Page<PrintingProjectInfo> getExamStudentList(@RequestBody PrintingProjectQuery query) {
        return printingProjectService.getPrintingProjectList(query);
    }

    @PostMapping("/{id}")
    @ApiOperation(value = "获取某印刷项目的信息")
    public PrintingProjectInfo getExamStudent(@PathVariable Long id) {
        return printingProjectService.getPrintingProjectById(id);
    }

    @PostMapping("/update")
    @ApiOperation(value = "更新印刷项目信息")
    public Result updateExamStudent(@RequestBody PrintingProjectInfo info) {
        printingProjectService.updatePrintingProject(info);
        return success();
    }

    @GetMapping("/all/init")
    public Result initAllData() {
        printingProjectService.initAllPrintingProject();
        return success();
    }

    @PostMapping("/org/list")
    @ApiOperation(value = "获取印刷学校列表")
    public List<OrgInfo> getOrgList() {
        //根据登录用户的不同角色取不同的学校数据
        UserInfo user = new UserInfo(getAccessUser());
        if (user.isSchoolUser()) {
            return Lists.newArrayList(user.getOrgInfo());
        } else if (user.isPM()) {
            return printingProjectService.getOrgList(user.getUserId(), null);
        } else if (user.isSupplier()) {
            return printingProjectService.getOrgList(null, user.getUserId());
        } else {
            return printingProjectService.getOrgList(null, null);
        }
    }

    @PostMapping("/exam/list")
    @ApiOperation(value = "获取印刷考试列表")
    public List<ExamInfo> getExamList(@RequestParam Long orgId) {
        return printingProjectService.getExamList(orgId);
    }

}